import { Component } from "@angular/core";
import { ActivatedRoute, Router } from "@angular/router";
import { BuildingService } from "../../service/monitoring-api.service";
import * as chartsData from "./data";
import { ChartOptions, ChartType, ChartDataset } from "chart.js";

@Component({
  selector: "app-detail",
  templateUrl: "./detail.component.html",
  styleUrls: ["./detail.component.css"],
})
export class DetailComponent {
  data: any;
  mode: string;
  breadcrumb: any;
  // chart
  public barChartOptions: ChartOptions = {
    responsive: true,
    scales: {
      x: {
        stacked: true,
      },
      y: {
        stacked: true,
      },
    },
  };
  public barChartLabels: string[] = [];
  public barChartType: ChartType = "bar";
  public barChartLegend = true;

  public barChartData: ChartDataset[] = [
    {
      data: [],
      label: "KWH Consumption",
      backgroundColor: "#00a5a8",
      borderColor: "#00a5a8",
      pointBackgroundColor: "#00a5a8",
      pointBorderColor: "#00a5a8",
      pointHoverBackgroundColor: "#fff",
      pointHoverBorderColor: "#00a5a8",
      barPercentage: 0.5,
      categoryPercentage: 0.5,
    },
    {
      data: [],
      label: "Water Consumption",
      backgroundColor: "#ff4081",
      borderColor: "#ff4081",
      pointBackgroundColor: "#ff4081",
      pointBorderColor: "#ff4081",
      pointHoverBackgroundColor: "#fff",
      pointHoverBorderColor: "#ff4081",
      barPercentage: 0.5,
      categoryPercentage: 0.5,
    },
    {
      type: "line", // override the default type
      data: [],
      label: "Appointment",
      backgroundColor: "rgba(0,255,255,0)",
      borderColor: "#1e9ff2",
      fill: false,
      pointBorderColor: "#1e9ff2",
      pointBackgroundColor: "#FFF",
      pointBorderWidth: 2,
      pointHoverBorderWidth: 2,
      pointRadius: 4,
    },
  ];
  //..........................

  // integrasi
  electric: any;
  water: any;
  device: any;
  room: any;
  //......
  constructor(
    private router: Router,
    private route: ActivatedRoute,
    private monitoringApiService: BuildingService
  ) {}

  ngOnInit() {
    this.route.data.subscribe((data) => {
      this.mode = data.mode;
    });
    this.breadcrumbLink();
    this.generateChartLabelsAndData();

    this.route.params.subscribe((params) => {
      const buildingId = params["id"];
      if (buildingId) {
        this.fetchData(buildingId);
        this.devicePerBuilding(buildingId);
      }
    });
  }

  breadcrumbLink() {
    if (this.mode === "room") {
      this.breadcrumb = {
        mainlabel: "Detail Monitoring",
        linkBack: "/monitoring/monitoring-room",
        isLinkBack: true,
        links: [
          {
            name: "Home",
            isLink: false,
            link: "",
          },
          {
            name: "Detail Monitoring",
            isLink: false,
            link: "",
          },
        ],
      };
    } else {
      this.breadcrumb = {
        mainlabel: "Detail Monitoring",
        linkBack: "/monitoring",
        isLinkBack: true,
        links: [
          {
            name: "Home",
            isLink: false,
            link: "",
          },
          {
            name: "Detail Monitoring",
            isLink: false,
            link: "",
          },
        ],
      };
    }
  }

  generateChartLabelsAndData() {
    const now = new Date();
    const year = now.getFullYear();
    const month = now.getMonth();
    const daysInMonth = new Date(year, month + 1, 0).getDate();

    for (let day = 1; day <= daysInMonth; day++) {
      const date = new Date(year, month, day);
      this.barChartLabels.push(date.toISOString().split("T")[0]); // Format YYYY-MM-DD

      // Example data generation, replace with your actual data logic
      this.barChartData[0].data?.push(Math.floor(Math.random() * 100));
      this.barChartData[1].data?.push(Math.floor(Math.random() * 100));
      this.barChartData[2].data?.push(Math.floor(Math.random() * 100));
    }
  }

  //integrasi
  fetchData(buildingId) {
    this.monitoringApiService
      .getRoomByBuildingId(buildingId)
      .subscribe((res) => {
        this.room = res.resp.map((entry) => entry.roomEntity).length;
      });
  }

  devicePerBuilding(buildingId) {
    this.monitoringApiService
      .listDevicePerBuilding(buildingId)
      .subscribe((res) => {
        this.device = res.resp.reduce(
          (sum, item) => sum + item.total_device,
          0
        );
      });
  }
}
